// package: supervisor
// file: info.proto

import * as info_pb from "./info_pb";
import {grpc} from "@improbable-eng/grpc-web";

type InfoServiceWorkspaceInfo = {
  readonly methodName: string;
  readonly service: typeof InfoService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof info_pb.WorkspaceInfoRequest;
  readonly responseType: typeof info_pb.WorkspaceInfoResponse;
};

export class InfoService {
  static readonly serviceName: string;
  static readonly WorkspaceInfo: InfoServiceWorkspaceInfo;
}

export type ServiceError = { message: string, code: number; metadata: grpc.Metadata }
export type Status = { details: string, code: number; metadata: grpc.Metadata }

interface UnaryResponse {
  cancel(): void;
}
interface ResponseStream<T> {
  cancel(): void;
  on(type: 'data', handler: (message: T) => void): ResponseStream<T>;
  on(type: 'end', handler: (status?: Status) => void): ResponseStream<T>;
  on(type: 'status', handler: (status: Status) => void): ResponseStream<T>;
}
interface RequestStream<T> {
  write(message: T): RequestStream<T>;
  end(): void;
  cancel(): void;
  on(type: 'end', handler: (status?: Status) => void): RequestStream<T>;
  on(type: 'status', handler: (status: Status) => void): RequestStream<T>;
}
interface BidirectionalStream<ReqT, ResT> {
  write(message: ReqT): BidirectionalStream<ReqT, ResT>;
  end(): void;
  cancel(): void;
  on(type: 'data', handler: (message: ResT) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'end', handler: (status?: Status) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'status', handler: (status: Status) => void): BidirectionalStream<ReqT, ResT>;
}

export class InfoServiceClient {
  readonly serviceHost: string;

  constructor(serviceHost: string, options?: grpc.RpcOptions);
  workspaceInfo(
    requestMessage: info_pb.WorkspaceInfoRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: info_pb.WorkspaceInfoResponse|null) => void
  ): UnaryResponse;
  workspaceInfo(
    requestMessage: info_pb.WorkspaceInfoRequest,
    callback: (error: ServiceError|null, responseMessage: info_pb.WorkspaceInfoResponse|null) => void
  ): UnaryResponse;
}

